@@ -13,7 +13,7 @@ Readonly::Hash my %LANG => (
 	'title' => 'Page title',
 );
 
-our $VERSION = 0.08;
+our $VERSION = 0.09;
 
 # Constructor.
 sub new {
@@ -65,6 +65,9 @@ sub new {
 	# Robots.
 	$self->{'robots'} = undef;
 
+	# RSS
+	$self->{'rss'} = undef;
+
 	# Script js code.
 	$self->{'script_js'} = [];
 
@@ -131,7 +134,7 @@ sub process {
 
 	my $css;
 	if ($self->{'css'}) {
-		$css = $self->{'css'}->flush."\n";
+		$css = $self->{'css'}->flush(1)."\n";
 	}
 
 	# Begin of page.
@@ -230,6 +233,18 @@ sub process {
 			);
 		}
 	}
+
+	if (defined $self->{'rss'}) {
+		$self->{'tags'}->put(
+			['b', 'link'],
+			['a', 'rel', 'alternate'],
+			['a', 'type', 'application/rss+xml'],
+			['a', 'title', 'RSS'],
+			['a', 'href', $self->{'rss'}],
+			['e', 'link'],
+		);
+	}
+
 	$self->{'tags'}->put(
 		['e', 'head'],
 		['b', 'body'],
@@ -416,6 +431,12 @@ Robots meta.
 
 Default value is undef.
 
+=item * C<rss>
+
+RSS link.
+
+Default value is undef.
+
 =item * C<script_js>
 
 List of JavaScript scripts.
@@ -492,9 +513,9 @@ Returns undef.
  # Process page
  $css->put(
         ['s', 'div'],
-	['d', 'color', 'red'],
-	['d', 'background-color', 'black'],
-	['e'],
+        ['d', 'color', 'red'],
+        ['d', 'background-color', 'black'],
+        ['e'],
  );
  $begin->process;
  $tags->put(
@@ -567,6 +588,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.08
+0.09
 
 =cut
